@@ -1,3 +1,5 @@
+import sys
+
 from mlflow.entities._mlflow_object import _MLflowObject
 from mlflow.protos.service_pb2 import Param as ProtoParam
 
@@ -8,6 +10,11 @@ class Param(_MLflowObject):
     """
 
     def __init__(self, key, value):
+        if "pyspark.ml" in sys.modules:
+            import pyspark.ml.param
+            if isinstance(key, pyspark.ml.param.Param):
+                key = key.name
+                value = str(value)
         self._key = key
         self._value = value
 
