@@ -3,8 +3,10 @@ Internal package providing a Python CRUD interface to MLflow experiments, runs,
 and model versions. This is a lower level API than the :py:mod:`mlflow.tracking.fluent` module,
 and is exposed in the :py:mod:`mlflow.tracking` module.
 """
+import logging
 
 from mlflow.entities import ViewType
+from mlflow.entities.model_registry.model_version_stages import ALL_STAGES
 from mlflow.exceptions import MlflowException
 from mlflow.protos.databricks_pb2 import FEATURE_DISABLED
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
@@ -12,7 +14,9 @@ from mlflow.tracking._model_registry.client import ModelRegistryClient
 from mlflow.tracking.registry import UnsupportedModelRegistryStoreURIException
 from mlflow.tracking._tracking_service import utils
 from mlflow.tracking._tracking_service.client import TrackingServiceClient
-from mlflow.utils import experimental
+from mlflow.utils import experimental, deprecated
+
+_logger = logging.getLogger(__name__)
 
 
 class MlflowClient(object):
@@ -203,6 +207,7 @@ class MlflowClient(object):
     def set_experiment_tag(self, experiment_id, key, value):
         """
         Set a tag on the experiment with the specified ID. Value is converted to a string.
+
         :param experiment_id: String ID of the experiment.
         :param key: Name of the tag.
         :param value: Tag value (converted to a string).
@@ -212,6 +217,7 @@ class MlflowClient(object):
     def set_tag(self, run_id, key, value):
         """
         Set a tag on the run with the specified ID. Value is converted to a string.
+
         :param run_id: String ID of the run.
         :param key: Name of the tag.
         :param value: Tag value (converted to a string)
@@ -259,6 +265,15 @@ class MlflowClient(object):
         """
         self._tracking_client.log_artifacts(run_id, local_dir, artifact_path)
 
+    def _record_logged_model(self, run_id, mlflow_model):
+        """
+        Record logged model info with the tracking server.
+
+        :param run_id: run_id under which the model has been logged.
+        :param mlflow_model: Model info to be recorded.
+        """
+        self._tracking_client._record_logged_model(run_id, mlflow_model)
+
     def list_artifacts(self, run_id, path=None):
         """
         List the artifacts for a run.
@@ -344,6 +359,18 @@ class MlflowClient(object):
         """
         return self._get_registry_client().create_registered_model(name)
 
+    @experimental
+    def rename_registered_model(self, name, new_name):
+        """
+        Update registered model name.
+
+        :param name: Name of the registered model to update.
+        :param new_name: New proposed name for the registered model.
+
+        :return: A single updated :py:class:`mlflow.entities.model_registry.RegisteredModel` object.
+        """
+        self._get_registry_client().rename_registered_model(name, new_name)
+
     @experimental
     def update_registered_model(self, name, new_name=None, description=None):
         """
@@ -351,11 +378,29 @@ class MlflowClient(object):
         be non-None. Backend raises exception if a registered model with given name does not exist.
 
         :param name: Name of the registered model to update.
-        :param new_name: (Optional) New proposed name for the registered model.
+        :param new_name: (Deprecated) New proposed name for the registered model.
+                         This argument is deprecated. Use the
+                         :py:func:`rename_registered_model <MlflowClient.rename_registered_model>`
+                         method to rename registered models instead.
         :param description: (Optional) New description.
         :return: A single updated :py:class:`mlflow.entities.model_registry.RegisteredModel` object.
         """
-        return self._get_registry_client().update_registered_model(name, new_name, description)
+        if new_name is None and description is None:
+            raise MlflowException("Attempting to update registered model with no new field values.")
+
+        if new_name is not None and new_name.strip() == "":
+            raise MlflowException("The new name must not be an empty string.")
+
+        res = None
+        if new_name is not None:
+            _logger.warning("The `new_name` argument in update_registered_model is deprecated."
+                            " Please use the `rename_registered_model` method instead.")
+            res = self._get_registry_client().rename_registered_model(name=name, new_name=new_name)
+            name = new_name
+        if description is not None:
+            res = self._get_registry_client().update_registered_model(name=name,
+                                                                      description=description)
+        return res
 
     @experimental
     def delete_registered_model(self, name):
@@ -372,16 +417,21 @@ class MlflowClient(object):
         """
         List of all registered models.
 
-        :return: List of :py:class:`mlflow.entities.registry.RegisteredModel` objects.
+        :return: List of :py:class:`mlflow.entities.model_registry.RegisteredModel` objects.
         """
         return self._get_registry_client().list_registered_models()
 
+    @deprecated(alternative="mlflow.tracking.client.get_registered_model", since="1.7")
     def get_registered_model_details(self, name):
+        return self.get_registered_model(name)
+
+    @experimental
+    def get_registered_model(self, name):
         """
         :param name: Name of the registered model to update.
-        :return: A single :py:class:`mlflow.entities.model_registry.RegisteredModelDetailed` object.
+        :return: A single :py:class:`mlflow.entities.model_registry.RegisteredModel` object.
         """
-        return self._get_registry_client().get_registered_model_details(name)
+        return self._get_registry_client().get_registered_model(name)
 
     @experimental
     def get_latest_versions(self, name, stages=None):
@@ -392,7 +442,7 @@ class MlflowClient(object):
         :param name: Name of the registered model to update.
         :param stages: List of desired stages. If input list is None, return latest versions for
                        for ALL_STAGES.
-        :return: List of `:py:class:`mlflow.entities.model_registry.ModelVersionDetailed` objects.
+        :return: List of :py:class:`mlflow.entities.model_registry.ModelVersion` objects.
         """
         return self._get_registry_client().get_latest_versions(name, stages)
 
@@ -418,10 +468,43 @@ class MlflowClient(object):
 
         :param name: Name of the containing registered model.
         :param version: Version number of the model version.
-        :param stage: New desired stage for this model version.
+        :param stage: (Deprecated) New desired stage forthis model version. This field is deprecated
+                      as of mlflow 1.7. Use transition_model_version_stage instead to update stage.
         :param description: New description.
+
+        :return: A single :py:class:`mlflow.entities.model_registry.ModelVersion` object.
         """
-        self._get_registry_client().update_model_version(name, version, stage, description)
+        if stage is None and description is None:
+            raise MlflowException("Attempting to update model version with no new field values.")
+        if stage is not None and stage.strip() == "":
+            raise MlflowException("The stage must not be an empty string.")
+
+        res = None
+        if stage is not None:
+            _logger.warning("'stage' field in update_model_version is deprecated. "
+                            "Use transition_model_stage instead.")
+            res = self._get_registry_client().transition_model_version_stage(name=name,
+                                                                             version=version,
+                                                                             stage=stage)
+        if description is not None:
+            res = self._get_registry_client().update_model_version(name=name, version=version,
+                                                                   description=description)
+        return res
+
+    @experimental
+    def transition_model_version_stage(self, name, version, stage):
+        """
+        Update model version stage.
+
+        :param name: Registered model name.
+        :param version: Registered model version.
+        :param new_stage: New desired stage for this model version.
+        :param archive_existing_versions: If this flag is set, all existing model
+               versions in the stage will be atomically moved to the "archived" stage.
+
+        :return: A single :py:class:`mlflow.entities.model_registry.ModelVersion` object.
+        """
+        return self._get_registry_client().transition_model_version_stage(name, version, stage)
 
     @experimental
     def delete_model_version(self, name, version):
@@ -433,14 +516,23 @@ class MlflowClient(object):
         """
         self._get_registry_client().delete_model_version(name, version)
 
-    @experimental
+    @deprecated("mlflow.tracking.client.get_model_version", "1.7")
     def get_model_version_details(self, name, version):
         """
         :param name: Name of the containing registered model.
         :param version: Version number of the model version.
-        :return: A single :py:class:`mlflow.entities.model_registry.ModelVersionDetailed` object.
+        :return: A single :py:class:`mlflow.entities.model_registry.ModelVersion` object.
         """
-        return self._get_registry_client().get_model_version_details(name, version)
+        return self._get_registry_client().get_model_version(name, version)
+
+    @experimental
+    def get_model_version(self, name, version):
+        """
+        :param name: Name of the containing registered model.
+        :param version: Version number of the model version.
+        :return: A single :py:class:`mlflow.entities.model_registry.ModelVersion` object.
+        """
+        return self._get_registry_client().get_model_version(name, version)
 
     @experimental
     def get_model_version_download_uri(self, name, version):
@@ -466,8 +558,8 @@ class MlflowClient(object):
         return self._get_registry_client().search_model_versions(filter_string)
 
     @experimental
-    def get_model_version_stages(self, name, version):
+    def get_model_version_stages(self, name, version):  # pylint: disable=unused-argument
         """
         :return: A list of valid stages.
         """
-        return self._get_registry_client().get_model_version_stages(name, version)
+        return ALL_STAGES
